@@ -1,6 +1,5 @@
 # main 76
 # sam robson
-
 import warnings
 import cython
 import pyximport; pyximport.install()
@@ -27,7 +26,6 @@ warnings.filterwarnings('ignore')
 
 pd.set_option("mode.chained_assignment", None)
 pd.set_option("display.notebook_repr_html", True)
-pd.set_option("display.width", None)
 pd.set_option('display.expand_frame_repr', True)
 pd.set_option('display.max_rows', 100)
 
@@ -35,10 +33,10 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group()
-@click.version_option("76.5.4", package_name="alacorder")
+@click.version_option("76.6.1", package_name="alacorder")
 def cli():
     """
-    ALACORDER beta 76.5.4
+    ALACORDER beta 76.6
 
     Alacorder processes case detail PDFs into data tables suitable for research purposes. Alacorder also generates compressed text archives from the source PDFs to speed future data collection from the same set of cases.
 
@@ -52,13 +50,13 @@ def cli():
 @click.option('--table', '-t', help="Table export choice (cases, fees, charges, disposition, filing, or all)")
 @click.option('--count', '-c', default=0, help='Total cases to pull from input', show_default=False)
 @click.option('--compress','-z', default=False, is_flag=True,
-              help="Compress exported file")
+              help="Compress exported file (Excel files not supported)")
 @click.option('--overwrite', '-o', default=False, help="Overwrite existing files at output path", is_flag=True,show_default=False)
+@click.option('--no-prompt','-s', default=False, is_flag=True, help="Skip user input / confirmation prompts")
+@click.option('--no-batch','-b', default=False, is_flag=True, help="Process all inputs as one batch")
 @click.option('--no-log','-q','log', default=False, is_flag=True, help="Don't print logs or progress to console")
 @click.option('--no-write', default=False, is_flag=True, help="Do not export to output path", hidden=True)
-@click.option('--no-prompt', default=False, is_flag=True, help="Skip user input / confirmation prompts")
 @click.option('--debug','-d', default=False, is_flag=True, help="Print extensive logs to console for developers")
-@click.option('--no-batch','-b', default=False, is_flag=True, help="Process all inputs as one batch")
 @click.version_option(package_name='alacorder', prog_name='ALACORDER', message='%(prog)s beta %(version)s')
 def table(input_path, output_path, count, table, overwrite, log, no_write, no_prompt, debug, no_batch, compress): # dropped dedupe, archive 
 
@@ -314,9 +312,28 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
 def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update, ignore_complete, debug):
     """
     Use headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE in an Excel spreadsheet to submit a list of queries for Alacorder to scrape.
-
+    
     USE WITH CHROME (TESTED ON MACOS) 
     KEEP YOUR COMPUTER POWERED ON AND CONNECTED TO THE INTERNET.
+    
+    Args:
+        listpath: (path-like obj) Query template path / input path
+        path: (path-like obj) Path to output/downloads directory 
+        cID (str): Alacourt.com Customer ID
+        uID (str): Alacourt.com User ID
+        pwd (str): Alacourt.com Password
+        qmax (int, optional): Max queries to pull from inputs
+        qskip (int, optional): Skip top n queries in inputs
+        speed (int, optional): Scrape rate multiplier
+        no_log (bool, optional): Do not print logs to console
+        no_update (bool, optional): Do not update input query file with completion status
+        debug (bool, optional): Print detailed logs to console
+
+    Returns:
+        [driver, query_out, query_writer]:
+            driver[0]: Google Chrome WebDriver() object 
+            query_out[1]: (pd.Series) Scraper queue
+            query_writer[2]: (pd.DataFrame) Updated input query file
     """
     if debug:
         sys.tracebacklimit = 10
@@ -372,7 +389,20 @@ def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update,
 
 
 def login(driver, cID, username, pwd, speed, no_log=False, path=""):
-
+    """Login to Alacourt.com using (driver) and auth (cID, username, pwd) at (speed) for browser download to directory at (path)
+    
+    Args:
+        driver (WebDriver): Google Chrome selenium.WebDriver() object
+        cID (str): Alacourt.com Customer ID
+        username (str): Alacourt.com User ID
+        pwd (str): Alacourt.com Password
+        speed (TYPE): Scrape rate multiplier
+        no_log (bool, optional): Do not print logs
+        path (str, optional): Set browser download path 
+    
+    Returns:
+        driver (WebDriver): Google Chrome selenium.WebDriver() object
+    """
     if driver == None:
         options = webdriver.ChromeOptions()
         options.add_experimental_option('prefs', {
@@ -427,7 +457,41 @@ def login(driver, cID, username, pwd, speed, no_log=False, path=""):
     return driver
 
 def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", speed=1, no_log=False, debug=False):
-
+    """
+    Collect PDFs via SJIS Party Search Form from Alacourt.com
+    Returns list of URLs for downloadPDF() to download
+    
+    Args:
+        driver (WebDriver): selenium/chrome web driver object 
+        name (str, optional): Name (LAST FIRST)
+        party_type (str, optional): "Defendants" | "Plaintiffs" | "ALL"
+        ssn (str, optional): Social Security Number
+        dob (str, optional): Date of Birth
+        county (str, optional): County
+        division (str, optional): "All Divisions"
+            "Criminal Only"
+            "Civil Only"
+            "CS - CHILD SUPPORT"
+            "CV - CIRCUIT - CIVIL"
+            "CC - CIRCUIT - CRIMINAL"
+            "DV - DISTRICT - CIVIL"
+            "DC - DISTRICT - CRIMINAL"
+            "DR - DOMESTIC RELATIONS"
+            "EQ - EQUITY-CASES"
+            "MC - MUNICIPAL-CRIMINAL"
+            "TP - MUNICIPAL-PARKING"
+            "SM - SMALL CLAIMS"
+            "TR - TRAFFIC"
+        case_year (str, optional): YYYY
+        filed_before (str, optional): M/DD/YYYY
+        filed_after (str, optional): M/DD/YYYY
+        speed (int, optional): Scrape rate multiplier
+        no_log (bool, optional): Do not print logs.
+        debug (bool, optional): Print detailed logs.
+    
+    Returns:
+        URL list to PDFs
+    """
     speed = speed * 1.5
 
 
